package ejb3;

import par.LogEntry;

import javax.ejb.Stateless;
import javax.jms.*;
import javax.naming.InitialContext;

@Stateless
public class LoggerBean implements Logger {

  public void sendEntry(final LogEntry logEntry) {
    QueueConnection cnn = null;
    QueueSession sess = null;
    QueueSender sender = null;

    try {
      final InitialContext ctx = new InitialContext();
      final Queue queue = (Queue) ctx.lookup("queue/myCustomLog");
      final QueueConnectionFactory factory = (QueueConnectionFactory) ctx.lookup("ConnectionFactory");
      cnn = factory.createQueueConnection();
      sess = cnn.createQueueSession(false, QueueSession.AUTO_ACKNOWLEDGE);

      final ObjectMessage objMessage = sess.createObjectMessage(logEntry);
      sender = sess.createSender(queue);
      sender.send(objMessage);
    }
    catch (Exception e) {
      e.printStackTrace();
    }
    finally {
      try {
        if (sess != null) {
          sess.close();
        }
      }
      catch (Exception e2) {
        System.err.println("Could not close logger session");
      }
      try {
        if (sender != null) {
          sender.close();
        }
      }
      catch (Exception e2) {
        System.err.println("Could not close logger sender");
      }
      try {
        if (cnn != null) {
          cnn.close();
        }
      }
      catch (Exception e2) {
        System.err.println("Could not close logger queue connection");
      }

    }

  }
}
